==> haskell-dense-linear-algebra-0.1.0.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dense-linear-algebra
version: 0.1.0.0
id: dense-linear-algebra-0.1.0.0-IIA89GbOnp3NtCLd2muw9
key: dense-linear-algebra-0.1.0.0-IIA89GbOnp3NtCLd2muw9
license: BSD-2-Clause
copyright: 2018 Author name here
maintainer: Alexey Khudaykov <alexey.skladnoy@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
synopsis: Simple and incomplete pure haskell implementation of linear algebra
description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.
category: Math, Statistics, Numeric
abi: 00f7a8a2217698f7f161713420e5609d
exposed: True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types
import-dirs: /usr/lib/ghc-8.6.4/site-local/dense-linear-algebra-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/dense-linear-algebra-0.1.0.0
hs-libraries: HSdense-linear-algebra-0.1.0.0-IIA89GbOnp3NtCLd2muw9
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    math-functions-0.3.1.0-2nHUjHLEI0SLJ3iUlVSM3j
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    vector-algorithms-0.8.0.1-zLqoLOQvkRBhoAdmbhXfr
    vector-binary-instances-0.2.5.1-D99ZmWt6MS3AuLha13B1Ep
    vector-th-unbox-0.2.1.6-1sxJpESaRmTGhnhBOhDreI
haddock-interfaces: /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock
haddock-html: /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dense-linear-algebra-0.1.0.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dense-linear-algebra
version: 0.1.0.0
id: dense-linear-algebra-0.1.0.0-DR1Zvd0p5yu2DpFeH6lxB3
key: dense-linear-algebra-0.1.0.0-DR1Zvd0p5yu2DpFeH6lxB3
license: BSD-2-Clause
copyright: 2018 Author name here
maintainer: Alexey Khudaykov <alexey.skladnoy@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
synopsis: Simple and incomplete pure haskell implementation of linear algebra
description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.
category: Math, Statistics, Numeric
abi: bc3a6eda0d101ad3bf9b90b1bee118ff
exposed: True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types
import-dirs: /usr/lib/ghc-8.6.4/site-local/dense-linear-algebra-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/dense-linear-algebra-0.1.0.0
hs-libraries: HSdense-linear-algebra-0.1.0.0-DR1Zvd0p5yu2DpFeH6lxB3
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    math-functions-0.3.1.0-2nHUjHLEI0SLJ3iUlVSM3j
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    vector-algorithms-0.8.0.1-zLqoLOQvkRBhoAdmbhXfr
    vector-binary-instances-0.2.5.1-D99ZmWt6MS3AuLha13B1Ep
    vector-th-unbox-0.2.1.6-1sxJpESaRmTGhnhBOhDreI
haddock-interfaces: /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock
haddock-html: /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
